Module: Editmode::ActionViewExtensions::EditmodeHelper
- Includes:
- Helper
- Included in:
- Editmode, ChunkValue
- Defined in:
- lib/editmode/action_view_extensions/editmode_helper.rb
Instance Method Summary collapse
- #api_root_url ⇒ Object
- #api_version ⇒ Object
- #chunk_collection(collection_identifier, **options, &block) ⇒ Object (also: #c)
- #chunk_display(label, identifier, options = {}, &block) ⇒ Object (also: #chunk)
- #chunk_field_value(parent_chunk_object, custom_field_identifier, options = {}) ⇒ Object
- #no_response_received(id = "") ⇒ Object
- #render_chunk(identifier, options = {}, &block) ⇒ Object (also: #E)
- #render_chunk_content(chunk_identifier, chunk_content, chunk_type, options = {}) ⇒ Object
- #render_custom_field(label, options = {}) ⇒ Object (also: #F)
- #require_field_id ⇒ Object
- #variable_parse!(content, variables, values) ⇒ Object
Methods included from Helper
#e, #parse_arguments, #render_custom_field_raw
Instance Method Details
#api_root_url ⇒ Object
13 14 15 |
# File 'lib/editmode/action_view_extensions/editmode_helper.rb', line 13 def api_root_url ENV["EDITMODE_OVERRIDE_API_URL"] || "https://api.editmode.com" end |
#api_version ⇒ Object
9 10 11 |
# File 'lib/editmode/action_view_extensions/editmode_helper.rb', line 9 def api_version # Todo Add Header Version end |
#chunk_collection(collection_identifier, **options, &block) ⇒ Object Also known as: c
17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/editmode/action_view_extensions/editmode_helper.rb', line 17 def chunk_collection(collection_identifier, **, &block) branch_params = params[:em_branch_id].present? ? "branch_id=#{params[:em_branch_id]}" : "" branch_id = params[:em_branch_id].presence = [:tags].presence || [] limit = [:limit].presence begin url_params = { :collection_identifier => collection_identifier, :branch_id => branch_id, :limit => limit, :tags => }.to_query url = URI(api_root_url) url.path = '/chunks' url.query = url_params cache_identifier = "collection_#{collection_identifier}#{branch_id}#{limit}#{.join}" cached_content_present = Rails.cache.exist?(cache_identifier) if !cached_content_present response = HTTParty.get(url) response_received = true if response.code == 200 end if !cached_content_present && !response_received raise "No response received" else chunks = Rails.cache.fetch(cache_identifier) do response['chunks'] end if chunks.any? content_tag :div, class: "chunks-collection-wrapper", data: {chunk_collection_identifier: collection_identifier} do chunks.each do |chunk| @custom_field_chunk = chunk yield end end end end rescue => error puts error return [] end end |
#chunk_display(label, identifier, options = {}, &block) ⇒ Object Also known as: chunk
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/editmode/action_view_extensions/editmode_helper.rb', line 127 def chunk_display(label, identifier, = {}, &block) branch_id = params[:em_branch_id] # This method should never show an error. # If anything goes wrong fetching content # We should just show blank content, not # prevent the page from loading. begin branch_params = branch_id.present? ? "branch_id=#{branch_id}" : "" cache_identifier = "chunk_#{identifier}#{branch_id}" url = "#{api_root_url}/chunks/#{identifier}?project_id=#{Editmode.project_id}&#{branch_params}" cached_content_present = Rails.cache.exist?(cache_identifier) if !cached_content_present response = HTTParty.get(url) response_received = true if response.code == 200 end if !cached_content_present && !response_received raise "No response received" else chunk_content = Rails.cache.fetch(cache_identifier) do response['content'] end chunk_type = Rails.cache.fetch("#{cache_identifier}_type") do response['chunk_type'] end render_chunk_content(identifier,chunk_content,chunk_type, ) end rescue => error # Show fallback content by default return content_tag("em-span", &block) if block_given? # Otherwise show a span with no content to # maintain layout content_tag("em-span", " ".html_safe) end end |
#chunk_field_value(parent_chunk_object, custom_field_identifier, options = {}) ⇒ Object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/editmode/action_view_extensions/editmode_helper.rb', line 67 def chunk_field_value(parent_chunk_object, custom_field_identifier, = {}) begin chunk_identifier = parent_chunk_object["identifier"] custom_field_item = parent_chunk_object["content"].detect {|f| f["custom_field_identifier"] == custom_field_identifier || f["custom_field_name"] == custom_field_identifier } if custom_field_item.present? render_chunk_content( custom_field_item["identifier"], custom_field_item["content"], custom_field_item["chunk_type"], { parent_identifier: chunk_identifier }.merge() ) end rescue => errors puts errors content_tag(:span, " ".html_safe) end end |
#no_response_received(id = "") ⇒ Object
197 198 199 |
# File 'lib/editmode/action_view_extensions/editmode_helper.rb', line 197 def no_response_received(id = "") "Sorry, we can't find a chunk using this identifier: \"#{id}\". This can happen if you've deleted a chunk on editmode.com or if your local cache is out of date. If it persists, try running Rails.cache clear." end |
#render_chunk(identifier, options = {}, &block) ⇒ Object Also known as: E
176 177 178 |
# File 'lib/editmode/action_view_extensions/editmode_helper.rb', line 176 def render_chunk(identifier, = {}, &block) chunk_display('label', identifier, , &block) end |
#render_chunk_content(chunk_identifier, chunk_content, chunk_type, options = {}) ⇒ Object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/editmode/action_view_extensions/editmode_helper.rb', line 86 def render_chunk_content(chunk_identifier, chunk_content, chunk_type, = {}) begin # Always sanitize the content!! chunk_content = ActionController::Base.helpers.sanitize(chunk_content) unless chunk_type == 'rich_text' css_class = [:class] if chunk_type == "image" display_type = "image" else display_type = [:display_type] || "span" end chunk_data = { :chunk => chunk_identifier, :chunk_editable => false, :chunk_type => chunk_type } if [:parent_identifier].present? chunk_data.merge!({parent_identifier: [:parent_identifier]}) end case display_type when "span" if chunk_type == "rich_text" content = content_tag("em-span", :class => "editmode-richtext-editor #{css_class}", :data => chunk_data.merge!({:chunk_editable => true}) ) do chunk_content.html_safe end else content_tag("em-span", :class => css_class, :data => chunk_data.merge!({:chunk_editable => true}) ) do chunk_content end end when "image" image_tag(chunk_content, :data => chunk_data, :class => css_class) end rescue => errors puts errors content_tag("em-span", " ".html_safe) end end |
#render_custom_field(label, options = {}) ⇒ Object Also known as: F
171 172 173 |
# File 'lib/editmode/action_view_extensions/editmode_helper.rb', line 171 def render_custom_field(label, ={}) chunk_field_value(@custom_field_chunk, label, ) end |
#require_field_id ⇒ Object
201 202 203 |
# File 'lib/editmode/action_view_extensions/editmode_helper.rb', line 201 def require_field_id "Field ID or Field Name is required to retrieve a collection item" end |
#variable_parse!(content, variables, values) ⇒ Object
182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/editmode/action_view_extensions/editmode_helper.rb', line 182 def variable_parse!(content, variables, values) tokens = content.scan(/\{{(.*?)\}}/) if tokens.any? tokens.flatten! tokens.each do |token| token_value = values[token.to_sym] || variables[token] || "" sanitized_value = ActionController::Base.helpers.sanitize(token_value) content.gsub!("{{#{token}}}", sanitized_value) end end content end |